@@ -15,12 +15,15 @@ pub type Result<T = ()> = StdResult<T, Error>;
 pub enum Error {
     /// I/O operations error.
     Io(io::Error),
+    /// Cannot parse request.
+    InvalidRequest,
 }
 
 impl Display for Error {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         match self {
             Self::Io(err) => err.fmt(f),
+            Self::InvalidRequest => writeln!(f, "Error: {:?}", Self::InvalidRequest),
         }
     }
 }
@@ -29,6 +32,7 @@ impl StdError for Error {
     fn source(&self) -> Option<&(dyn StdError + 'static)> {
         match self {
             Self::Io(err) => Some(err),
+            _ => None,
         }
     }
 }
