@@ -6,7 +6,7 @@
 )]
 
 //! # Voidy
-//! ## A library to handle http requests asynchronously.
+//! ## A library to handle HTTP/2 requests asynchronously.
 
 #[doc(hidden)]
 pub use error::Result;
@@ -15,4 +15,5 @@ pub use error::Result;
 pub use server::Server;
 
 pub mod error;
+pub mod http;
 mod server;
