@@ -1,4 +1,4 @@
-use async_std::net::{SocketAddr, TcpListener, ToSocketAddrs};
+use async_std::net::{SocketAddr, TcpListener, TcpStream, ToSocketAddrs};
 
 use crate::Result;
 
@@ -11,7 +11,7 @@ pub struct Server {
 impl Server {
     /// Creates a new [Server] with the specified address.
     ///
-    /// # Examples
+    /// ## Examples
     ///
     /// Create a [Server] bound to `127.0.0.1:8000`.
     ///
@@ -28,9 +28,27 @@ impl Server {
         Ok(Self { listener })
     }
 
+    /// Accept a new request.
+    ///
+    /// ## Examples
+    ///
+    /// ```no_run
+    /// use voidy::Server;
+    ///
+    /// # fn main() -> voidy::Result { async_std::task::block_on(async {
+    /// let server = Server::bind("127.0.0.1:8000").await?;
+    /// let request = server.accept().await?;
+    /// # Ok(()) }) }
+    /// ```
+    pub async fn accept(&self) -> Result<(TcpStream, SocketAddr)> {
+        let conn = self.listener.accept().await?;
+
+        Ok(conn)
+    }
+
     /// Returns the local address that [Server] is bound to.
     ///
-    /// # Examples
+    /// ## Examples
     ///
     /// Assert that the local address bound to [Server] is `127.0.0.1:8000`.
     ///
@@ -51,3 +69,9 @@ impl Server {
         Ok(self.listener.local_addr()?)
     }
 }
+
+impl From<TcpListener> for Server {
+    fn from(listener: TcpListener) -> Self {
+        Self { listener }
+    }
+}
